@@ -5,6 +5,7 @@ from typing import List
 from typing import Union
 
 from ._core import find_function_def_in_class_def
+from ._core import get_class_meta_data
 from ._core import get_func_meta_data
 from ._core import get_imports
 
@@ -104,12 +105,7 @@ class ModuleInfo:
         return Imports(get_imports(self._tree))
 
     def get_funcs_info(self, only_func_names: bool = False) -> Dict[str, List[ast.Call]]:
-        """Return a list of all the func call that are executed inside the funcs
-        Example:
-            def foo():
-                with open("test.json", "r") as f:
-                    load(f)
-            the function when called for get_func_call_in_func will return ast.Call object of open, load
+        """R
         """
 
         func_info = {}
@@ -124,4 +120,11 @@ class ModuleInfo:
         return func_info
 
     def get_classes_info(self) -> Dict[str, List[ast.Call]]:
-        pass
+
+        class_info = {}
+
+        for child in ast.walk(self._tree):
+            if isinstance(child, ast.ClassDef):
+                class_info[child.name] = get_class_meta_data(
+                    child, read_file_code(self.filename))
+        return class_info
